==> strauss-0.1.1.tar.gz: strauss-0.1.1/README.md <==
# STRAUSS
***S**onification **T**ools and **R**esources for **A**stronomers **U**sing **S**ound **S**ynthesis*

![Sonification Tools & Resources for Astronomers Using Sound Synthesis](/misc/strauss_logo.png "STRAUSS logo")

## Sonification and STRAUSS

*"Sonification"* is the process of conveying data via the medium of sound. Sonification can be used to make scientific data more accessible to those with visual impairments, enhance visualisations and movies, and even convey information more efficiently than by visual means. The *STRAUSS* python package is intended to make sonification simple for both scientific and outreach applications.

## Getting Started

Access the [full documentation here](https://strauss.readthedocs.io/) *(under construction!)* and read more about the associated [Audio Universe project here](https://www.audiouniverse.org/).

Releases are registered on [PyPI](https://pypi.org/project/strauss). *STRAUSS* may be installed using pip.

Development is occurring at the [*STRAUSS* GitHub page](https://github.com/james-trayford/strauss.git strauss).

Make a copy of the *STRAUSS* repository via SSH,

`git clone git@github.com:james-trayford/strauss.git strauss`

or HTTPS if you don't have [SSH keys set up](https://docs.github.com/en/github/authenticating-to-github/connecting-to-github-with-ssh),

`git clone https://github.com/james-trayford/strauss.git strauss`

*STRAUSS* may then be installed using pip

`cd strauss`

`pip install .`

For development purposes, you can instead use:

`pip install -e .`

where the `-e` option allows a local install, such that you can modify and run the source code on the fly without needing to reinstall each time. 

We recommend using a conda environment to avoid package conflicts. Type

`conda env create -f environment.yml`

before `pip install -e .`

and activate the environment with

`conda activate strauss`

## Acknowledgments
The *STRAUSS* code has benefited from funding via an [Royal Astronomical Society Eduaction & Outreach grant award](https://ras.ac.uk/awards-and-grants/outreach/education-outreach-small-grants-scheme), providing hardware and software for sound development and spatialisation testing.

==> strauss-0.1.2.tar.gz: strauss-0.1.2/README.md <==
# STRAUSS
***S**onification **T**ools and **R**esources for **A**stronomers **U**sing **S**ound **S**ynthesis*

![Sonification Tools & Resources for Astronomers Using Sound Synthesis](https://github.com/james-trayford/strauss/tree/main/misc/strauss_logo.png)

## Sonification and STRAUSS

*"Sonification"* is the process of conveying data via the medium of sound. Sonification can be used to make scientific data more accessible to those with visual impairments, enhance visualisations and movies, and even convey information more efficiently than by visual means. The *STRAUSS* python package is intended to make sonification simple for both scientific and outreach applications.

## Getting Started

Access the [full documentation here](https://strauss.readthedocs.io/) *(under construction!)* and read more about the associated [Audio Universe project here](https://www.audiouniverse.org/).

Releases are registered on [PyPI](https://pypi.org/project/strauss). *STRAUSS* may be installed using pip.

Development is occurring at the [*STRAUSS* GitHub page](https://github.com/james-trayford/strauss.git).

Make a copy of the *STRAUSS* repository via SSH,

`git clone git@github.com:james-trayford/strauss.git strauss`

or HTTPS if you don't have [SSH keys set up](https://docs.github.com/en/github/authenticating-to-github/connecting-to-github-with-ssh),

`git clone https://github.com/james-trayford/strauss.git strauss`

*STRAUSS* may then be installed using pip

`cd strauss`

`pip install .`

For development purposes, you can instead use:

`pip install -e .`

where the `-e` option allows a local install, such that you can modify and run the source code on the fly without needing to reinstall each time. 

We recommend using a conda environment to avoid package conflicts. Type

`conda env create -f environment.yml`

before `pip install -e .`

and activate the environment with

`conda activate strauss`

## Acknowledgments
The *STRAUSS* code has benefited from funding via an [Royal Astronomical Society Education & Outreach grant award](https://ras.ac.uk/awards-and-grants/outreach/education-outreach-small-grants-scheme), providing hardware and software for sound development and spatialisation testing.
